pub struct EntityRef<M> { /* private fields */ }Expand description
Reference to one entity.
Implementations
Sourceimpl<M> EntityRef<M>
impl<M> EntityRef<M>
Sourcepub async fn tell(&self, message: M) -> ShardingResult<()>
pub async fn tell(&self, message: M) -> ShardingResult<()>
Send one message at-most-once.
Sourcepub async fn passivate(&self) -> ShardingResult<()>
pub async fn passivate(&self) -> ShardingResult<()>
Passivate this entity if it is currently running.
The entity actor is stopped and removed from the local runtime on its current owner. A later message respawns the entity on demand. If the shard is moving, passivation is ordered through the same bounded handoff buffer as user messages.
Sourcepub async fn ask<R, F>(
&self,
timeout: Duration,
make_message: F,
) -> ShardingResult<R>
pub async fn ask<R, F>( &self, timeout: Duration, make_message: F, ) -> ShardingResult<R>
Send one message that carries a sharding ReplyPort.