InMemoryStore

Struct InMemoryStore 

pub struct InMemoryStore { /* private fields */ }
In-memory remembered entity store.

This store is intended for tests and single-process development. It survives shard rebalance when all regions share the same InMemoryStore value, but it is process memory and does not survive process death.

Implementations

Source

impl InMemoryStore

pub fn new() -> Self

Create an empty in-memory store.