pub struct InMemoryStore { /* private fields */ }Expand description
In-memory remembered entity store.
This store is intended for tests and single-process development. It survives
shard rebalance when all regions share the same InMemoryStore value, but it
is process memory and does not survive process death.
Implementations
Sourceimpl InMemoryStore
impl InMemoryStore